API docs for “spamfighter.core.counters.AtomCounterEternal”

# Class s.c.c.AtomCounterEternal(object):

Part of spamfighter.core.counters View Source View In Hierarchy

Одиночный счетчик за "весь период" (с момента создания счетчика).

Instance Variables | counter | значение счетчика
| start | время создания счетчика, секунды UTC (type: `int` )

Method | __init__ | Конструктор.
Method | value | Текущее значение счетчика для данного периода.
Method | count | Число увеличений счетчика.
Method | period | Период времени, за который собирается значение счетчика.
Method | increment | Увеличить значение счетчика на указанное значение.
Method | label | Подпись счетчика, описывающая период его работы.
Method | __getstate__ | Undocumented
Method | __setstate__ | Undocumented

def __init__(self): (source)
Конструктор.

def value(self): (source)
Текущее значение счетчика для данного периода.

def count(self): (source)
Число увеличений счетчика.

Returns | (type: `int` )

def period(self): (source)
Период времени, за который собирается значение счетчика.

Returns | период времени, секунды (type: `int` )

def increment(self, value=1): (source)
Увеличить значение счетчика на указанное значение.

Parameters | value | значение инкремента

def label(self): (source)
Подпись счетчика, описывающая период его работы.

Returns | (type: `str` )

def __getstate__(self): (source)
Undocumented
def __setstate__(self, state): (source)
Undocumented